;; moved to C source code
;;
;;	(defvar delete-by-moving-to-trash nil
;;	  "Non nil means redirect to `move-file-to-trash'
;;	by `delete-file' or `delete-directory'")

(or (functionp 'orig-backup-extract-version)
    (fset 'orig-backup-extract-version (symbol-function 'backup-extract-version)))
;; Note: The following function can deal with directory properly.
(defun backup-extract-version (fn)
  "Given the name of a numeric backup file, return the backup number.
Uses the free variable `backup-extract-version-start', whose value should be
the index in the name where the version number begins."
  (if (and (string-match "[0-9]+~/?$" fn backup-extract-version-start)
	   (= (match-beginning 0) backup-extract-version-start))
      (string-to-int (substring fn backup-extract-version-start -1))
      0))

(defvar trash-directory "~/.Trash"
  "Trash directory to move file (or directory) by `move-file-to-trash',
when system-specific move-file-to-trash doesn't exist.
If set \".Trash\", always move to the directory under default-directory.
See also `delete-by-moving-to-trash'.")

(defun move-file-to-trash (filename)
  "Move file (or directory) named FILENAME.
Usually this function is called by `delete-file' or `delete-directory',
so must return nil if succeed."
  (interactive "fMove file to trash: ")
  (cond
   ((fboundp 'system-move-file-to-trash)
    (system-move-file-to-trash filename))
   (t
    (let* ((trash-dir	(expand-file-name trash-directory))
	   (fn		(directory-file-name (expand-file-name filename)))
	   (fn-nondir	(file-name-nondirectory fn))
	   (new-fn	(expand-file-name fn-nondir trash-dir)))
      (or (file-directory-p trash-dir)
	  (make-directory trash-dir t))
      (and (file-exists-p new-fn)
	   ;; make new-fn unique.
	   ;; example: "~/.Trash/abc.txt" -> "~/.Trash/abc.txt.~1~"
	   (let ((version-control t))
	     (setq new-fn (car (find-backup-file-name new-fn)))))
      ;; stop processing if fn is same or parent directory of trash-dir.
      (and (string-match fn trash-dir)
	   (error (message "filename `%s' is same or parent directory of trash-directory."
			   filename)))
      (rename-file fn new-fn)))))
